@@ -1,3 +1,5 @@
+from typing import Optional, Union
+
 from .units import MICROMOLES_PER_LITER, MILLIGRAMS_PER_DECILITER, MILLIMOLES_PER_LITER
 
 
@@ -5,7 +7,12 @@ class ConversionNotHandled(Exception):
     pass
 
 
-def convert_units(value, units_from=None, units_to=None, places=None):
+def convert_units(
+    value: Union[int, float],
+    units_from: Optional[str] = None,
+    units_to: Optional[str] = None,
+    places: Optional[int] = None,
+) -> Union[int, float]:
     places = places or 4
     converted_value = value
     if value and units_from and units_to and units_from != units_to:
